@@ -2,12 +2,12 @@
 NCAGLMmenu<-function()
 {
 cat("\n")
-  file.menu <- c("NCA-->GLM",
-                 "Demo for NCA-->GLM",
+  file.menu <- c("NCA--> ANOVA (lm)",
+                 "Run demo for NCA--> ANOVA (lm)",
                  "Back to the previous step",
                  "Quit")
  cat("\n")
-  pick <- menu(file.menu, title = " << NCA-->GLM menu >> ")
+  pick <- menu(file.menu, title = " << NCA--> ANOVA (lm) menu >> ")
     if (pick == 1){
       cat("\n")
         NCAGLMdata()
