@@ -2,36 +2,32 @@
 sizemenu<-function()
 {
 cat("\n")
-  file.menu <- c("Sample size estimation (raw data)",
-                 "Sample size estimation (log transformation)",
-                 "Run demo for sample size estimation (raw data)",
+  file.menu <- c("Sample size estimation ",
+                 "Run demo for sample size estimation ",
                  "Back to top menu",
                  "Quit")
    cat("\n")
   pick <- menu(file.menu, title = " << Sample size estimation menu >> ")
     if (pick == 1){
       cat("\n")
-        rawdata()
+        logdata()
         }
     else {
     if (pick == 2){
         cat("\n")
-        logdata()
+       demosize() 
        }
     else {
     if (pick == 3){
         cat("\n")
-        demosize()
+       go() 
          }
    else {
     if (pick == 4){
         cat("\n")
-        go()
+        cat("\nBye~~ \n\n")
          }
-    else {
-    if (pick == 5){
-        cat("\nBye~~ \n\n")}
-         } 
+    
        }
      }
   }
